@@ -41,6 +41,16 @@ class CreateDBClusterRequest(RpcRequest):
 
 	def set_DBClusterDescription(self, DBClusterDescription):  # String
 		self.add_query_param('DBClusterDescription', DBClusterDescription)
+	def get_ProxyClass(self): # String
+		return self.get_query_params().get('ProxyClass')
+
+	def set_ProxyClass(self, ProxyClass):  # String
+		self.add_query_param('ProxyClass', ProxyClass)
+	def get_ProxyType(self): # String
+		return self.get_query_params().get('ProxyType')
+
+	def set_ProxyType(self, ProxyType):  # String
+		self.add_query_param('ProxyType', ProxyType)
 	def get_ScaleMax(self): # String
 		return self.get_query_params().get('ScaleMax')
 
@@ -120,6 +130,11 @@ class CreateDBClusterRequest(RpcRequest):
 
 	def set_DBMinorVersion(self, DBMinorVersion):  # String
 		self.add_query_param('DBMinorVersion', DBMinorVersion)
+	def get_ProvisionedIops(self): # Long
+		return self.get_query_params().get('ProvisionedIops')
+
+	def set_ProvisionedIops(self, ProvisionedIops):  # Long
+		self.add_query_param('ProvisionedIops', ProvisionedIops)
 	def get_AutoRenew(self): # Boolean
 		return self.get_query_params().get('AutoRenew')
 
@@ -130,11 +145,21 @@ class CreateDBClusterRequest(RpcRequest):
 
 	def set_HotStandbyCluster(self, HotStandbyCluster):  # String
 		self.add_query_param('HotStandbyCluster', HotStandbyCluster)
+	def get_StoragePayType(self): # String
+		return self.get_query_params().get('StoragePayType')
+
+	def set_StoragePayType(self, StoragePayType):  # String
+		self.add_query_param('StoragePayType', StoragePayType)
 	def get_ZoneId(self): # String
 		return self.get_query_params().get('ZoneId')
 
 	def set_ZoneId(self, ZoneId):  # String
 		self.add_query_param('ZoneId', ZoneId)
+	def get_StorageAutoScale(self): # String
+		return self.get_query_params().get('StorageAutoScale')
+
+	def set_StorageAutoScale(self, StorageAutoScale):  # String
+		self.add_query_param('StorageAutoScale', StorageAutoScale)
 	def get_TDEStatus(self): # Boolean
 		return self.get_query_params().get('TDEStatus')
 
@@ -155,6 +180,11 @@ class CreateDBClusterRequest(RpcRequest):
 
 	def set_ScaleRoNumMax(self, ScaleRoNumMax):  # String
 		self.add_query_param('ScaleRoNumMax', ScaleRoNumMax)
+	def get_StandbyAZ(self): # String
+		return self.get_query_params().get('StandbyAZ')
+
+	def set_StandbyAZ(self, StandbyAZ):  # String
+		self.add_query_param('StandbyAZ', StandbyAZ)
 	def get_ClientToken(self): # String
 		return self.get_query_params().get('ClientToken')
 
@@ -180,6 +210,21 @@ class CreateDBClusterRequest(RpcRequest):
 
 	def set_GDNId(self, GDNId):  # String
 		self.add_query_param('GDNId', GDNId)
+	def get_LooseXEngine(self): # String
+		return self.get_query_params().get('LooseXEngine')
+
+	def set_LooseXEngine(self, LooseXEngine):  # String
+		self.add_query_param('LooseXEngine', LooseXEngine)
+	def get_LoosePolarLogBin(self): # String
+		return self.get_query_params().get('LoosePolarLogBin')
+
+	def set_LoosePolarLogBin(self, LoosePolarLogBin):  # String
+		self.add_query_param('LoosePolarLogBin', LoosePolarLogBin)
+	def get_Architecture(self): # String
+		return self.get_query_params().get('Architecture')
+
+	def set_Architecture(self, Architecture):  # String
+		self.add_query_param('Architecture', Architecture)
 	def get_ResourceOwnerAccount(self): # String
 		return self.get_query_params().get('ResourceOwnerAccount')
 
@@ -190,11 +235,26 @@ class CreateDBClusterRequest(RpcRequest):
 
 	def set_OwnerAccount(self, OwnerAccount):  # String
 		self.add_query_param('OwnerAccount', OwnerAccount)
+	def get_LooseXEngineUseMemoryPct(self): # String
+		return self.get_query_params().get('LooseXEngineUseMemoryPct')
+
+	def set_LooseXEngineUseMemoryPct(self, LooseXEngineUseMemoryPct):  # String
+		self.add_query_param('LooseXEngineUseMemoryPct', LooseXEngineUseMemoryPct)
 	def get_UsedTime(self): # String
 		return self.get_query_params().get('UsedTime')
 
 	def set_UsedTime(self, UsedTime):  # String
 		self.add_query_param('UsedTime', UsedTime)
+	def get_DBNodeNum(self): # Integer
+		return self.get_query_params().get('DBNodeNum')
+
+	def set_DBNodeNum(self, DBNodeNum):  # Integer
+		self.add_query_param('DBNodeNum', DBNodeNum)
+	def get_StorageUpperBound(self): # Long
+		return self.get_query_params().get('StorageUpperBound')
+
+	def set_StorageUpperBound(self, StorageUpperBound):  # Long
+		self.add_query_param('StorageUpperBound', StorageUpperBound)
 	def get_VPCId(self): # String
 		return self.get_query_params().get('VPCId')
 
@@ -215,6 +275,11 @@ class CreateDBClusterRequest(RpcRequest):
 
 	def set_DBVersion(self, DBVersion):  # String
 		self.add_query_param('DBVersion', DBVersion)
+	def get_StrictConsistency(self): # String
+		return self.get_query_params().get('StrictConsistency')
+
+	def set_StrictConsistency(self, StrictConsistency):  # String
+		self.add_query_param('StrictConsistency', StrictConsistency)
 	def get_CloneDataPoint(self): # String
 		return self.get_query_params().get('CloneDataPoint')
 
