@@ -41,6 +41,20 @@ class CreateDBEndpointAddressRequest(RpcRequest):
 
 	def set_ConnectionStringPrefix(self, ConnectionStringPrefix):  # String
 		self.add_query_param('ConnectionStringPrefix', ConnectionStringPrefix)
+	def get_ZoneInfos(self): # RepeatList
+		return self.get_query_params().get('ZoneInfo')
+
+	def set_ZoneInfos(self, ZoneInfo):  # RepeatList
+		for depth1 in range(len(ZoneInfo)):
+			if ZoneInfo[depth1].get('VSwitchId') is not None:
+				self.add_query_param('ZoneInfo.' + str(depth1 + 1) + '.VSwitchId', ZoneInfo[depth1].get('VSwitchId'))
+			if ZoneInfo[depth1].get('ZoneId') is not None:
+				self.add_query_param('ZoneInfo.' + str(depth1 + 1) + '.ZoneId', ZoneInfo[depth1].get('ZoneId'))
+	def get_SecurityGroupId(self): # String
+		return self.get_query_params().get('SecurityGroupId')
+
+	def set_SecurityGroupId(self, SecurityGroupId):  # String
+		self.add_query_param('SecurityGroupId', SecurityGroupId)
 	def get_DBEndpointId(self): # String
 		return self.get_query_params().get('DBEndpointId')
 
@@ -71,3 +85,8 @@ class CreateDBEndpointAddressRequest(RpcRequest):
 
 	def set_NetType(self, NetType):  # String
 		self.add_query_param('NetType', NetType)
+	def get_VPCId(self): # String
+		return self.get_query_params().get('VPCId')
+
+	def set_VPCId(self, VPCId):  # String
+		self.add_query_param('VPCId', VPCId)
