@@ -36,6 +36,11 @@ class DescribeDBClusterParametersRequest(RpcRequest):
 
 	def set_ResourceOwnerId(self, ResourceOwnerId):  # Long
 		self.add_query_param('ResourceOwnerId', ResourceOwnerId)
+	def get_DescribeType(self): # String
+		return self.get_query_params().get('DescribeType')
+
+	def set_DescribeType(self, DescribeType):  # String
+		self.add_query_param('DescribeType', DescribeType)
 	def get_ResourceOwnerAccount(self): # String
 		return self.get_query_params().get('ResourceOwnerAccount')
 
