@@ -25,68 +25,59 @@ class ModifyDBClusterMigrationRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'polardb', '2017-08-01', 'ModifyDBClusterMigration','polardb')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_ResourceOwnerId(self):
+	def get_ResourceOwnerId(self): # Long
 		return self.get_query_params().get('ResourceOwnerId')
 
-	def set_ResourceOwnerId(self,ResourceOwnerId):
-		self.add_query_param('ResourceOwnerId',ResourceOwnerId)
-
-	def get_ConnectionStrings(self):
+	def set_ResourceOwnerId(self, ResourceOwnerId):  # Long
+		self.add_query_param('ResourceOwnerId', ResourceOwnerId)
+	def get_ConnectionStrings(self): # String
 		return self.get_query_params().get('ConnectionStrings')
 
-	def set_ConnectionStrings(self,ConnectionStrings):
-		self.add_query_param('ConnectionStrings',ConnectionStrings)
-
-	def get_SecurityToken(self):
+	def set_ConnectionStrings(self, ConnectionStrings):  # String
+		self.add_query_param('ConnectionStrings', ConnectionStrings)
+	def get_SecurityToken(self): # String
 		return self.get_query_params().get('SecurityToken')
 
-	def set_SecurityToken(self,SecurityToken):
-		self.add_query_param('SecurityToken',SecurityToken)
-
-	def get_NewMasterInstanceId(self):
+	def set_SecurityToken(self, SecurityToken):  # String
+		self.add_query_param('SecurityToken', SecurityToken)
+	def get_NewMasterInstanceId(self): # String
 		return self.get_query_params().get('NewMasterInstanceId')
 
-	def set_NewMasterInstanceId(self,NewMasterInstanceId):
-		self.add_query_param('NewMasterInstanceId',NewMasterInstanceId)
-
-	def get_ResourceOwnerAccount(self):
+	def set_NewMasterInstanceId(self, NewMasterInstanceId):  # String
+		self.add_query_param('NewMasterInstanceId', NewMasterInstanceId)
+	def get_ResourceOwnerAccount(self): # String
 		return self.get_query_params().get('ResourceOwnerAccount')
 
-	def set_ResourceOwnerAccount(self,ResourceOwnerAccount):
-		self.add_query_param('ResourceOwnerAccount',ResourceOwnerAccount)
-
-	def get_DBClusterId(self):
+	def set_ResourceOwnerAccount(self, ResourceOwnerAccount):  # String
+		self.add_query_param('ResourceOwnerAccount', ResourceOwnerAccount)
+	def get_DBClusterId(self): # String
 		return self.get_query_params().get('DBClusterId')
 
-	def set_DBClusterId(self,DBClusterId):
-		self.add_query_param('DBClusterId',DBClusterId)
-
-	def get_OwnerAccount(self):
+	def set_DBClusterId(self, DBClusterId):  # String
+		self.add_query_param('DBClusterId', DBClusterId)
+	def get_OwnerAccount(self): # String
 		return self.get_query_params().get('OwnerAccount')
 
-	def set_OwnerAccount(self,OwnerAccount):
-		self.add_query_param('OwnerAccount',OwnerAccount)
-
-	def get_SourceRDSDBInstanceId(self):
+	def set_OwnerAccount(self, OwnerAccount):  # String
+		self.add_query_param('OwnerAccount', OwnerAccount)
+	def get_SourceRDSDBInstanceId(self): # String
 		return self.get_query_params().get('SourceRDSDBInstanceId')
 
-	def set_SourceRDSDBInstanceId(self,SourceRDSDBInstanceId):
-		self.add_query_param('SourceRDSDBInstanceId',SourceRDSDBInstanceId)
-
-	def get_SwapConnectionString(self):
+	def set_SourceRDSDBInstanceId(self, SourceRDSDBInstanceId):  # String
+		self.add_query_param('SourceRDSDBInstanceId', SourceRDSDBInstanceId)
+	def get_SwapConnectionString(self): # String
 		return self.get_query_params().get('SwapConnectionString')
 
-	def set_SwapConnectionString(self,SwapConnectionString):
-		self.add_query_param('SwapConnectionString',SwapConnectionString)
-
-	def get_OwnerId(self):
+	def set_SwapConnectionString(self, SwapConnectionString):  # String
+		self.add_query_param('SwapConnectionString', SwapConnectionString)
+	def get_OwnerId(self): # Long
 		return self.get_query_params().get('OwnerId')
 
-	def set_OwnerId(self,OwnerId):
-		self.add_query_param('OwnerId',OwnerId)
\ No newline at end of file
+	def set_OwnerId(self, OwnerId):  # Long
+		self.add_query_param('OwnerId', OwnerId)
