@@ -61,6 +61,11 @@ class ModifyDBClusterPrimaryZoneRequest(RpcRequest):
 
 	def set_OwnerId(self, OwnerId):  # Long
 		self.add_query_param('OwnerId', OwnerId)
+	def get_IsSwitchOverForDisaster(self): # String
+		return self.get_query_params().get('IsSwitchOverForDisaster')
+
+	def set_IsSwitchOverForDisaster(self, IsSwitchOverForDisaster):  # String
+		self.add_query_param('IsSwitchOverForDisaster', IsSwitchOverForDisaster)
 	def get_VSwitchId(self): # String
 		return self.get_query_params().get('VSwitchId')
 
@@ -71,6 +76,11 @@ class ModifyDBClusterPrimaryZoneRequest(RpcRequest):
 
 	def set_PlannedStartTime(self, PlannedStartTime):  # String
 		self.add_query_param('PlannedStartTime', PlannedStartTime)
+	def get_VPCId(self): # String
+		return self.get_query_params().get('VPCId')
+
+	def set_VPCId(self, VPCId):  # String
+		self.add_query_param('VPCId', VPCId)
 	def get_ZoneId(self): # String
 		return self.get_query_params().get('ZoneId')
 
